import { NextRequest, NextResponse } from "next/server";
import type { Client, Prisma } from "@prisma/client";

import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";

export async function PATCH(
  req: Request,
  { params }: { params: { id: string } },
) {
  try {
    const user = await getCurrentUser();
    if (!user) {
      return new NextResponse("Unauthorized", { status: 401 });
    }

    const data = await req.json();
    const client = await prisma.client.findUnique({
      where: { id: params.id },
    });

    if (!client || client.userId !== user.id) {
      return new NextResponse("Forbidden", { status: 403 });
    }

    const updateData = {
      name: data.name,
      description: data.description,
      home: data.home,
      logo: data.logo,
      redirectUri: data.redirectUri,
    } satisfies Partial<Prisma.ClientUpdateInput>;

    // 单独处理 allowedUsers 字段
    if (Array.isArray(data.allowedUsers)) {
      await prisma.$executeRaw`UPDATE clients SET "allowedUsers" = ${data.allowedUsers}::text[] WHERE id = ${params.id}`;
    }

    const updatedClient = await prisma.client.update({
      where: { id: params.id },
      data: updateData,
    });

    return NextResponse.json(updatedClient);
  } catch (error) {
    console.error("[CLIENT_UPDATE]", error);
    return new NextResponse("Internal Error", { status: 500 });
  }
}

export async function DELETE(
  _request: Request,
  { params }: { params: { id: string } },
) {
  try {
    const user = await getCurrentUser();
    if (!user) {
      return new NextResponse("Unauthorized", { status: 401 });
    }

    const client = await prisma.client.findUnique({
      where: { id: params.id },
    });

    if (!client) {
      return new NextResponse("Not Found", { status: 404 });
    }

    if (client.userId !== user.id) {
      return new NextResponse("Forbidden", { status: 403 });
    }

    // 删除相关的授权记录
    await prisma.authorization.deleteMany({
      where: { clientId: params.id },
    });

    // 删除相关的访问令牌
    await prisma.accessToken.deleteMany({
      where: { clientId: params.id },
    });

    // 删除相关的授权码
    await prisma.code.deleteMany({
      where: { clientId: params.id },
    });

    // 删除客户端
    await prisma.client.delete({
      where: { id: params.id },
    });

    return new NextResponse(null, { status: 204 });
  } catch (error) {
    console.error("[CLIENT_DELETE]", error);
    return new NextResponse("Internal Error", { status: 500 });
  }
}
