"use client";

import { useEffect } from "react";
import Image from "next/image";
import Link from "next/link";
import { usePathname, useRouter } from "next/navigation";
import { ChevronDown, User } from "lucide-react";
import { signOut, useSession } from "next-auth/react";

import { cn } from "@/lib/utils";
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";

import DynamicLogo from "../dynamic-logo";
import { ThemeToggle } from "../theme-toggle";
import { Button } from "../ui/button";

export function NavBar() {
  const { data: session, status } = useSession();
  const router = useRouter();
  const pathname = usePathname();
  const user = session?.user;

  const handleSignOut = async () => {
    await signOut({ redirect: false });
    router.refresh();
    router.push("/");
  };

  return (
    <nav className="sticky top-0 z-10 bg-white shadow-md dark:bg-gray-800">
      <div className="mx-auto max-w-7xl px-4 sm:px-6 lg:px-8">
        <div className="flex h-14 items-center justify-between">
          <div className="flex items-center">
            <Link href="/" className="flex items-center space-x-3">
              <DynamicLogo />
              <h1 className="text-2xl font-bold text-[#25263A] dark:text-white">
                Q58 Connect
              </h1>
            </Link>

            {user && (
              <div className="ml-8 flex items-center space-x-1">
                <Link
                  href="/dashboard"
                  className={cn(
                    "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                    pathname === "/dashboard"
                      ? "bg-accent text-accent-foreground"
                      : "text-muted-foreground",
                  )}
                >
                  控制台
                </Link>
                <Link
                  href="/dashboard/clients"
                  className={cn(
                    "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                    pathname.startsWith("/dashboard/clients")
                      ? "bg-accent text-accent-foreground"
                      : "text-muted-foreground",
                  )}
                >
                  应用管理
                </Link>
                <Link
                  href="/dashboard/settings"
                  className={cn(
                    "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                    pathname === "/dashboard/settings"
                      ? "bg-accent text-accent-foreground"
                      : "text-muted-foreground",
                  )}
                >
                  设置
                </Link>
                {user.role === "ADMIN" && (
                  <>
                    <div className="mx-2 h-4 w-px bg-border" />
                    <Link
                      href="/admin"
                      className={cn(
                        "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                        pathname === "/admin"
                          ? "bg-accent text-accent-foreground"
                          : "text-muted-foreground",
                      )}
                    >
                      管理后台
                    </Link>
                    <DropdownMenu>
                      <DropdownMenuTrigger asChild>
                        <Button
                          variant="ghost"
                          size="sm"
                          className={cn(
                            "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                            pathname.startsWith("/admin/") &&
                              pathname !== "/admin"
                              ? "bg-accent text-accent-foreground"
                              : "text-muted-foreground",
                          )}
                        >
                          管理功能
                          <ChevronDown className="ml-1 h-4 w-4" />
                        </Button>
                      </DropdownMenuTrigger>
                      <DropdownMenuContent align="start">
                        <DropdownMenuItem asChild>
                          <Link
                            href="/admin/users"
                            className={cn(
                              "w-full",
                              pathname === "/admin/users" && "bg-accent",
                            )}
                          >
                            用户列表
                          </Link>
                        </DropdownMenuItem>
                        <DropdownMenuItem asChild>
                          <Link
                            href="/admin/clients"
                            className={cn(
                              "w-full",
                              pathname === "/admin/clients" && "bg-accent",
                            )}
                          >
                            应用管理
                          </Link>
                        </DropdownMenuItem>
                        <DropdownMenuItem asChild>
                          <Link
                            href="/admin/authorizations"
                            className={cn(
                              "w-full",
                              pathname === "/admin/authorizations" &&
                                "bg-accent",
                            )}
                          >
                            授权管理
                          </Link>
                        </DropdownMenuItem>
                        <DropdownMenuItem asChild>
                          <Link
                            href="/admin/logs"
                            className={cn(
                              "w-full",
                              pathname === "/admin/logs" && "bg-accent",
                            )}
                          >
                            系统日志
                          </Link>
                        </DropdownMenuItem>
                      </DropdownMenuContent>
                    </DropdownMenu>
                  </>
                )}
              </div>
            )}
          </div>

          <div className="flex items-center space-x-4">
            <ThemeToggle />
            {status === "loading" ? (
              <Button
                variant="ghost"
                size="icon"
                className="relative h-8 w-8"
                disabled
              >
                <User className="h-4 w-4" />
              </Button>
            ) : user ? (
              <div className="flex items-center gap-3">
                <Avatar className="h-8 w-8">
                  <AvatarImage src={user.avatarUrl || undefined} />
                  <AvatarFallback>
                    {user.name?.charAt(0) || user.username?.charAt(0)}
                  </AvatarFallback>
                </Avatar>
                <Button
                  variant="ghost"
                  size="sm"
                  onClick={handleSignOut}
                  className="text-muted-foreground hover:text-red-600"
                >
                  退出
                </Button>
              </div>
            ) : (
              <Link href="/sign-in">
                <Button
                  variant="outline"
                  size="sm"
                  className="border-[#25263A] text-[#25263A] hover:bg-[#25263A] hover:text-white dark:border-[#A0A1B2] dark:text-[#A0A1B2] dark:hover:bg-[#A0A1B2] dark:hover:text-[#25263A]"
                >
                  登录
                </Button>
              </Link>
            )}
          </div>
        </div>
      </div>
    </nav>
  );
}
